pandascore-python
==================

A `pandascore.co <https://pandascore.co>`_ API client library for Python. Provides a simple interface that returns a dictionary of the JSON response. Supports Python 2.7 and 3.6

More information about the API is available at `PandaScore API Reference <https://api.pandascore.co/doc>`_.

Supported APIs
-------------------

- Core API
- League of Legends API

For more information, please visit the `Github repo <https://github.com/tiamat-studios/pandascore-python>`_.
